<?php
 /**
 * AEIOU Parser that makes use of the SimpleXML PHP extension.
 * Adapted from Wordpress-Importer ver. 0.6 plugin (http://wordpress.org/extend/plugins/wordpress-importer/)
 */
class AEIOU_Parser_SimpleXML {
	function parse( $file ) {

		$internal_errors = libxml_use_internal_errors(true);
		$xml = simplexml_load_file( $file );
		// halt if loading produces an error
		if ( ! $xml ){
			echo __( 'There was an error when reading this AEIOU file', AEIOU::LANG_DOMAIN ) . "\n";
			return false;
		}
		$aeiou_version = $xml->xpath('/users/@version');
		
		if ( ! $aeiou_version ){
			echo __( 'This does not appear to be a AEIOU file, missing/invalid AEIOU version number', AEIOU::LANG_DOMAIN ) . "\n";
			return false;
		}

		$aeiou_version = (string) trim( $aeiou_version[0] );

		// confirm that we are dealing with the correct file format
		if ( ! preg_match( '/^\d+\.\d+$/', $aeiou_version ) ){
			echo __( 'This does not appear to be a AEIOU file, missing/invalid AEIOU version number', AEIOU::LANG_DOMAIN ) . "\n";
			return false;
		}

		$users = array();
		
		// grab users
		$count = 0;
		foreach ( $xml->xpath('/users/user') as $userArray ) {
			$count +=1;
			$md = array();
			
			$user = $userArray->children( );
			if(isset($user->metadata)){
				
				foreach($user->metadata->meta as  $meta){
					
					$metaArr = (array)$meta;
					$key = (string) $metaArr['@attributes']['key'];
					$value = (string) $meta;
					
					$md[$key] =base64_decode( $value );
				}
				
			}
			
			$users[] = array(
				
				'user_login' 			=> (string) $user->user_login,
				'user_password' 		=> (string) isset($user->user_password)?$usr->user_password:'',
				'user_nicename' 		=> (string) $user->user_nicename,
				'user_email' 			=> (string) $user->user_email,
				'user_url' 				=> (string) $user->user_url,
				'user_registered' 		=> (string) $user->user_registered,
				'user_activation_key' 	=> (string) $user->user_activation_key,
				'user_status' 			=> (string) $user->user_status,
				'display_name' 			=> (string) $user->display_name,
				'metadata'				=> $md
			);
		}
		
		echo sprintf(__("Found %d users in the import file", AEIOU::LANG_DOMAIN), $count ) . "\n";
		
		return $users;
	}
}

